@@ -19,13 +19,19 @@ def patch_zope(path, wrapper):
             self, msgid, mapping, context, target_language, default
             )
 
+        real_value = value
+
         # Register with utility; note that arguments appear in a
         # slightly different order.
+        if mapping is not None:
+            for key, string in mapping.items():
+                value = value.replace(string, '${%s}' % key)
+
         recorder.register(
             value, msgid, domain, mapping, context, target_language, default
             )
 
-        return value
+        return real_value
 
     TranslationDomain.translate = wraps(TranslationDomain.translate)(translate)
 
